Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/corefx.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatt Mitchell <mmitche@microsoft.com>2017-06-01 19:46:03 +0300
committerMatt Mitchell <mmitche@microsoft.com>2017-06-01 19:46:03 +0300
commit336f565193562f6f5cc9fd7c0d069d6cd2d5ded6 (patch)
tree4c6ba84428912fdf26f096804884e2a705e88e99 /netci.groovy
parent3bc879503708488ce4365a312a3667e1653a4c41 (diff)
Temporarily add OSX10.12 back into CI
Not available yet in pipeline, add triggers for traditional jobs back temporarily
Diffstat (limited to 'netci.groovy')
-rw-r--r--netci.groovy4
1 files changed, 2 insertions, 2 deletions
diff --git a/netci.groovy b/netci.groovy
index e8b1282ef6..e6ec812250 100644
--- a/netci.groovy
+++ b/netci.groovy
@@ -341,8 +341,8 @@ def targetGroupOsMapInnerloop = ['netcoreapp': ['Windows_NT', 'Ubuntu14.04', 'Ub
// Set up triggers
if (isPR) {
targetGroupString = targetGroupString.replaceAll('_', ' ');
- // Set PR trigger only run netfx jobs automatically on every PR, the other legs are covered by the new portable pipeline legs
- if (targetGroup == 'netfx') {
+ // Set PR trigger only run netfx jobs automatically on every PR, the other legs except OSX10.12 are covered by the new portable pipeline legs
+ if (targetGroup == 'netfx' || osName == 'OSX10.12') {
Utilities.addGithubPRTriggerForBranch(newJob, branch, "Innerloop ${targetGroupString}${osName} ${configurationGroup} ${archGroup} Build and Test")
}
else {